netapp_ontap.models.cluster_peer_remote API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_peer_remote`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterPeerRemoteSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterPeerRemote object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `ip_addresses GET POST PATCH`

    The IPv4 addresses, IPv6 addresses, or hostnames of the peers.

  `name GET`

    The name of the remote cluster.

    Example: cluster2

  `serial_number GET`

    The serial number of the remote cluster.

    Example: 4048820-60-9